
/*
xpvox copyright (c) 2005 Jan Panteltje

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


#include "xpvox.h"


#define COM1BASE    0x3f8
#define COM2BASE    0x2f8
#define COM3BASE    0x3e8
#define COM4BASE    0x2e8


int get_combase(char *serial_device, int *combase)
{
if(debug_flag)
	{
	fprintf(stderr,\
	"get_combase(): arg serial device=%s\n", serial_device);
	}

if(! serial_device) return 0;

if(strcmp(serial_device, "/dev/cua0") == 0) *combase = COM1BASE;
else if(strcmp(serial_device, "/dev/cua1") == 0) *combase = COM2BASE;
else if(strcmp(serial_device, "/dev/cua2") == 0) *combase = COM3BASE;
else if(strcmp(serial_device, "/dev/cua3") == 0) *combase = COM4BASE;

/*
Added ttySx because of this in /var/log/messages:
tty_io.c: process 1104 used obsolete /dev/cua1-
update software to use /dev/ttyS1
*/
else if(strcmp(serial_device, "/dev/ttyS0") == 0) *combase = COM1BASE;
else if(strcmp(serial_device, "/dev/ttyS1") == 0) *combase = COM2BASE;
else if(strcmp(serial_device, "/dev/ttyS2") == 0) *combase = COM3BASE;
else if(strcmp(serial_device, "/dev/ttyS3") == 0) *combase = COM4BASE;
else 
	{
	printf("Invalid serial device %s\n", serial_device);

	return 0;
	}

return 1;
} /* end function get_combase */


int set_rts(char *device, int state)
/* sets RTS to on or off */
{
int a = 0; // -Wall
int combase;

if(debug_flag)
	{
	fprintf(stderr, "set_rts(): device=%s state=%d using transmission_inhibit_flag=%d no_io_flag=%d\n",\
	device, state, transmission_inhibit_flag, no_io_flag);
	}

rts_requested_on_flag = state;

/* set RTS to 0 if in transmission inhibit mode */
if(transmission_inhibit_flag && (state == 1) ) state = 0;

#define RTS 1

if(! get_combase(device, &combase) )
	{
	return 0;
	}

if(! no_io_flag)
	{
	a = inb(combase + 4);
	}

// /* bit is inverted */

if(state == 1)
	{
	a |= (1 << RTS); /* set bit 1 (RTS) */
	}
else
	{
	a &= ~(1 << RTS); /* reset bit 1 (RTS) */
	}

if(! no_io_flag) outb(a, combase + 4);

rts_is_on_flag = state;
	
return 1;
} /* end function set_rts */


